pred_known_to_hold_modulo_regions

Function pred_known_to_hold_modulo_regions 

fn pred_known_to_hold_modulo_regions<'db>(
    infcx: &InferCtxt<'db>,
    param_env: ParamEnv<'db>,
    pred: impl Upcast<DbInterner<'db>, Predicate<'db>>,
) -> bool
FIXME(@lcnr): this function doesn’t seem right and shouldn’t exist?

Ping me on zulip if you want to use this method and need help with finding an appropriate replacement.